# system config
LOG_DIR = None
LOG_LEVEL = 'DEBUG'

# Client settings
CLIENT_MQTT_TOPICS = None
CLIENT_KAFKA_TOPICS = None
CLIENT_URI = None
CLIENT_USERNAME = None
CLIENT_PASSWORD = None

# LoRa server settings
LORA_DRIVER = None

# Producer settings
PRODUCER_DRIVER = None
PRODUCER_TARGET = None
PRODUCER_HOSTS = None
PRODUCER_DATABASE = None
PRODUCER_USERNAME = None
PRODUCER_PASSWORD = None
